import json
import logging
import argparse
import os
import clients as app_clients

from botocore.exceptions import ClientError

logger = logging.getLogger("create_r_and_d_role_manager")
logger.setLevel(logging.INFO)
formatter = logging.Formatter("%(asctime)s %(levelname)s - %(message)s")
handler_console = logging.StreamHandler()
handler_console.setFormatter(formatter)
logger.addHandler(handler_console)

def main(environment=None):
    CURRENT_FILE_PATH = os.path.dirname(os.path.abspath(__file__))
    environment_choices = ['localdev', 'dev08', 'dev01', 'test03']
    parser = argparse.ArgumentParser(description="Migrate Secops Role Manager")
    parser.add_argument('-e', '--environment', required=False, choices=environment_choices)
    args = parser.parse_known_args()[0]

    if environment is not None and environment not in environment_choices:
            raise ValueError('Incorrect environment choice')
    env = args.environment if environment is None else environment

    dynamo_client = app_clients.DynamoDbClient(env)
    dynamo_client.setClientEnvironment()

    with open('../local/batch-write-r-and-d-role-manager.json') as f:
        data = f.read()
        r_and_d_role_manager_definition = json.loads(data)

    hub = get_hub(env)
    r_and_d_role_manager_definition['{}_access_roles'.format(hub)] = r_and_d_role_manager_definition.pop('localdev_access_roles')

    # Must add 25 items at a time due to AWS batchwrite restrictions
    arr = r_and_d_role_manager_definition['{}_access_roles'.format(hub)]
    start = 0
    while start < len(arr):
        stop = min(start+25, len(arr))
        item = {'{}_access_roles'.format(hub): arr[start:stop]}
        try:
            dynamo_client.batch_write(item)
            start = stop
        except ClientError as ex:
            logger.error("Batch Write failed for R&D Role Manager, error: %s)" % ex.response)
            break


def get_hub(environment):
    hub = None
    if environment.startswith('local'):
        hub = 'localdev'
    elif environment.startswith('dev'):
        hub = 'hub-dev-us'
    elif environment.startswith('test'):
        hub = 'hub04'

    if hub == None:
        raise Exception("Could not get Hub configuration for environment {}".format(environment))
    logger.info("Hub Environment %s " % hub)
    return hub

if __name__ == "__main__":
    main()