#!/usr/bin/env bash

if [ -z "$1" ]; then
	echo "Need source environment to execute script, exiting..."
	exit 1
fi

if [[ ! "$1" =~ ^(localdev|dev08|dev01|test03|eap01|prod01|prod02|prod04|prod05|prod06|prodnrt|prodsyd)$ ]]; then
    echo "$1 is not a valid source environment, exiting..."
    exit 1
fi

if [ -z "$2" ]; then
	echo "Need destination environment to execute script, exiting..."
	exit 1
fi

if [[ ! "$2" =~ ^(localdev|hub02|hub04|hub-prod-us|hub-prod-eu|hub-prod-ap)$ ]]; then
    echo "$1 is not a valid destination environment, exiting..."
    exit 1
fi

SRC_ENVIRONMENT=$1
DEST_ENVIRONMENT=$2

echo "Beginning migration for users and connectors:"

# Create Python Virtual Env and install required packages
virtualenv -p python3 venv3

if [ -d "venv3" ]; then
    . venv3/bin/activate
    echo "Installing pip requirements..."
    pip install -r requirements.txt
else
    exit 1
fi

python principal-name-migration.py -s ${SRC_ENVIRONMENT} -d ${DEST_ENVIRONMENT}