#!/usr/bin/env bash
DIR="$( cd "$( dirname "${BASH_SOURCE[0]}" )" && pwd )"

if [ -z "$1" ]; then
	echo "Need environment to execute script, exiting..."
	exit 1
fi

if [[ ! "$1" =~ ^(localdev|dev08|dev01|test03|eap01|prod01|prod02|prod04|prod05|prod06|prodnrt|prodsyd)$ ]]; then
    echo "$1 is not an environment, exiting..."
    exit 1
fi

ENVIRONMENT=$1
MIGRATION_ARG=""

while (( "$#" )); do
  case "$2" in
    --migration)
	  MIGRATION_ARG="--migration"
      shift 1
      ;;
    -*|--*=) # unsupported flags
      echo "Error: Unsupported flag $2" >&2
      exit 1
      ;;
 	*)
      shift
      ;;
  esac
done

echo "Beginning RBAC Role Permissions Scoped Migration on: " ${ENVIRONMENT}

# Create Python Virtual Env and install required packages
virtualenv -p python3 venv3

if [ -d "venv3" ]; then
    . venv3/bin/activate
    echo "Installing pip requirements..."
    pip install -r ../requirements.txt
else
    exit 1
fi

python migrate_role_permission_scoped.py -e ${ENVIRONMENT} ${MIGRATION_ARG}